==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_peace_town_divination.lua <==
function E0090()
    MNA()CMU("CS_Grand")FAI(0)
end
function E0091()
    MNA()CMU("CS_Grand")FAI(1)
end
function E0092()
    MNA()CMU("CS_Grand")FAI(2)
end
function E0093()
    MNA()CMU("CS_Grand")FAI(3)
end
function E0094()
    MNA()CMU("CS_Grand")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",20,31)
end

function Misery1Chat()
    DNP("Misery1Chat")
    if(FLJ("GiveToMisery")) then
        Misery1Chat_Firefly()
    else
        Misery1Chat_Getout()
    end
end

function Misery1Chat_Firefly()
    KEY()
    FAC("misery_normal")
    MYB(0,PLY())
    MS3("怎么又是你们，")WAS()NOD()
    CAT("\n没看到外面的宠物禁止入内标志嘛...")NOD()CLR()
    CAT("不过你们敢再次进来，")NOD()
    CAT("\n还挺有勇气的。")NOD()
    CAT("\n不过我可不会帮你们的忙。")NOD()
    CAT("\n所以这次到底是什么事...")NOD()CLR()
    GIT("Firefly")
    FAC("jack_normal")CAT("\n我们给你带了这个...")NOD()CLR()
    FAC("misery_normal")
    CAT("原来是萤火虫啊，")NOD()
    FAC("misery_excite")CAT("\n那我就感激的收下了。")NOD()CLR()
    ITS("Firefly")
    GIT()
    FAC("misery_normal")CAT("不过，")NOD()
    CAT("\n我感知到你身上还有其他")
    CAT("\n富有魔力的物品。")NOD()CLR()
    CAT("为了确认安全")
    CAT("\n给我看一下到底是什么吧...")NOD()CLR()
    GIT("DemonFlower")
    FAC("jack_normal")CAT("\n是这个嘛？")NOD()CLR()
    FAC("misery_normal")CAT("\n嗯，好像是一块有趣的材料。")NOD()CLR()
    FAC("jack_normal")CAT("那我把它也送给你吧，")NOD()
    CAT("\n反正我们也用不到。")NOD()CLR()
    FAC("misery_normal")CAT("\n那我也收下了。")NOD()CLR()
    ITS("DemonFlower")
    GIT()
    CAT("不过突然一下收到两个礼物，")NOD()
    CAT("\n不做点回应对生意客流也不好。")NOD()CLR()
    FAC("misery_excite")CAT("\n干脆你们来抽个签吧！")NOD()CLO()
    FAO(0)
    WAI(64)
    MOV(18,12,PLY())
    MOV(19,12,1-PLY())
    SLR(0)
    AMC("normal")
    FAI(2)
    WAI(32)
    FAC("misery_normal")MS3("\n结果怎么样？")NOD()CLR()
    FAC("jack_><")CAT("\n我是")FCL(0)CAT("【大凶】")FCL()NOD()CLR()
    FAC()CAT("\n我也是")FCL(0)CAT("【大凶】")FCL()NOD()CLR()
    FAC("misery_normal")CAT("看样子这是命运安排好的，")NOD()
    CAT("\n我变更不了。")NOD()CLR()
    FAC("misery_excite")CAT("你们今天接下来")
    CAT("\n会遇到很有趣的事情呢。")NOD()CLR()
    FAC("misery_normal")CAT("对了，你们是要寻找一只咪咪卡嘛？")NOD()
    CAT("\n那么去珍卡那吧。")NOD()
    CAT("\n她的小狗们肯定能帮上忙。")NOD()CLR()
    CAT("还有，穿越火之洞窟的闸门")
    CAT("\n必须要有火精灵的魔法才行，")NOD()
    CAT("\n我这就给你们安排上。")NOD()CLO()
    WAI(32)
    ANP("Misery1","magic_powerful")
    WAI(50)
    ITS("Fireball")
    ITP("GhostFire")
    CMU("CS_Fanfale1")
    GIT("GhostFire")
    MS3("=火球=")
    CAT("\n升级成了 =幽灵火球=")WAI(160)NOD()RMU()CLR()GIT()
    AMC("ghostfire_get")
    FAC("jack_normal")CAT("\n谢谢你帮我们！")NOD()CLR()
    FAC("misery_normal")CAT("不，")NOD()
    FAC("misery_excite")CAT("\n这只是能让我欣赏到")
    CAT("\n你们垂死挣扎表演的准备工作。")NOD()CLR()
    CAT("\n祝你们今天愉快~")NOD()CLO()
    PMU(1)
    FAO(0)
    TRA("CS_peace_town_hotel","GoFindJenka",15,19)

end

function Misery1Chat_Getout()
    KEY()
    FAC("misery_normal")
    MYB(0,PLY())
    MS3("停下，")WAS()NOD()
    CAT("\n这里只欢迎人类旅客。")NOD()CLO()
    FAO(0)
    MOV(18,12,PLY())
    MOV(19,12,1-PLY())
    SLR(0)
    AMC("normal")
    AMC("hide_gun")
    FAI(2)
    ---[[
    FAC("misery_normal")
    MS3("\n.")WAI(8) CAT(".")WAI(8) CAT(".")WAI(8) CAT(".")WAI(8) CAT(".")WAI(8)CLR()
    CAT("不过，")NOD()
    CAT("\n我记得你们好像是我以前")
    CAT("\n抓过的那几只咪咪卡之一。")NOD()CLR()
    CAT("现在那只小咪咪卡和")
    CAT("\n红眼的都已经复活了..")NOD()CLR()
    CAT("\n你们到这里有何贵干？")NOD()CLR()
    FAC("jack_normal")CAT("最近咪咪卡村附近有怪物出现，")NOD()
    CAT("\n把数和多隆子抓走了，")NOD()
    FAC("jack_><")CAT("\n我想求你帮我找找她们在哪...")NOD()CLR()
    CMU("XXXX")
    FAC("misery_normal")CAT("别做梦了，")NOD()
    CAT("\n我不是你们的灯神。")NOD()CLR()
    FAC("misery_not_well")CAT("\n还有这里宠物禁止入内！")NOD()CLO()
    --]]
    --用泡泡把赶走
    ANP("Misery1","magic")
    SNP("CS_bubble_catcher",16,10,0,"mainLayer","Bubble1")--泡泡
    ANP("Bubble1","set_target")
    ANP("Bubble1",MCN(PLY()))
    WAI(24)
    if(MCN(PLY()) == "CS_mychar_jack") then
        ANP("Bubble1","caught_jack")
    else
        ANP("Bubble1","caught_santa")
    end
    HMC(PLY())
    SOU("CS_021_bubble")
    ANP("Bubble1","set_target")
    ANP("Bubble1","Door_GoPeaceTown")
    WAI(16)
    --捕获玩家2
    ANP("Misery1","magic")
    SNP("CS_bubble_catcher",16,10,0,"mainLayer","Bubble2")--泡泡
    ANP("Bubble2","set_target")
    ANP("Bubble2",MCN(1-PLY()))
    WAI(24)
    SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)
    if(MCN(1-PLY()) == "CS_mychar_jack") then
        ANP("Bubble2","caught_jack")
    else
        ANP("Bubble2","caught_santa")
    end
    HMC(1-PLY())
    SOU("CS_021_bubble")
    ANP("Bubble2","set_target")
    ANP("Bubble2","Door_GoPeaceTown")
    WAI(32)
    DNP("Bubble1")
    WAI(36)
    DNP("Bubble2")
    FAO(2)TRA("CS_peace_town","GetOutDivination",20,31)
end

==> ocstore25_10_6.zip: OcStore/Prgm/data/map/CS_peace_town_divination.lua <==
function E0090()
    MNA()CMU("CS_Grand")FAI(0)
end
function E0091()
    MNA()CMU("CS_Grand")FAI(1)
end
function E0092()
    MNA()CMU("CS_Grand")FAI(2)
end
function E0093()
    MNA()CMU("CS_Grand")FAI(3)
end
function E0094()
    MNA()CMU("CS_Grand")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",20,31)
end

function Misery1Chat()
    DNP("Misery1Chat")
    if(FLJ("GiveToMisery")) then
        Misery1Chat_Firefly()
    else
        Misery1Chat_Getout()
    end
end

function Misery1Chat_Firefly()
    KEY()
    FAC("misery_normal")
    MYB(0,PLY())
    MS3("怎么又是你们，")WAS()NOD()
    CAT("\n没看到外面的宠物禁止入内标志嘛...")NOD()CLR()
    CAT("不过你们敢再次进来，")NOD()
    CAT("\n还挺有勇气的。")NOD()
    CAT("\n不过我可不会帮你们的忙。")NOD()
    CAT("\n所以这次到底是什么事...")NOD()CLR()
    GIT("Firefly")
    FAC("jack_normal")CAT("\n我们给你带了这个...")NOD()CLR()
    FAC("misery_normal")
    CAT("原来是萤火虫啊，")NOD()
    FAC("misery_excite")CAT("\n那我就感激的收下了。")NOD()CLR()
    ITS("Firefly")
    GIT()
    FAC("misery_normal")CAT("不过，")NOD()
    CAT("\n我感知到你身上还有其他")
    CAT("\n富有魔力的物品。")NOD()CLR()
    CAT("为了确认安全")
    CAT("\n给我看一下到底是什么吧...")NOD()CLR()
    GIT("DemonFlower")
    FAC("jack_normal")CAT("\n是这个嘛？")NOD()CLR()
    FAC("misery_normal")CAT("\n嗯，好像是一块有趣的材料。")NOD()CLR()
    FAC("jack_normal")CAT("那我把它也送给你吧，")NOD()
    CAT("\n反正我们也用不到。")NOD()CLR()
    FAC("misery_normal")CAT("\n那我也收下了。")NOD()CLR()
    ITS("DemonFlower")
    GIT()
    CAT("不过突然一下收到两个礼物，")NOD()
    CAT("\n不做点回应对生意客流也不好。")NOD()CLR()
    FAC("misery_excite")CAT("\n干脆你们来抽个签吧！")NOD()CLO()
    FAO(0)
    WAI(64)
    MOV(18,12,PLY())
    MOV(19,12,1-PLY())
    SLR(0)
    AMC("normal")
    FAI(2)
    WAI(32)
    FAC("misery_normal")MS3("\n结果怎么样？")NOD()CLR()
    FAC("jack_><")CAT("\n我是")FCL(0)CAT("【大凶】")FCL()NOD()CLR()
    FAC()CAT("\n我也是")FCL(0)CAT("【大凶】")FCL()NOD()CLR()
    FAC("misery_normal")CAT("看样子这是命运安排好的，")NOD()
    CAT("\n我变更不了。")NOD()CLR()
    FAC("misery_excite")CAT("你们今天接下来")
    CAT("\n会遇到很有趣的事情呢。")NOD()CLR()
    FAC("misery_normal")CAT("对了，你们是要寻找一只咪咪卡嘛？")NOD()
    CAT("\n那么去珍卡那吧。")NOD()
    CAT("\n她的小狗们肯定能帮上忙。")NOD()CLR()
    CAT("还有，穿越火之洞窟的闸门")
    CAT("\n必须要有火精灵的魔法才行，")NOD()
    CAT("\n我这就给你们安排上。")NOD()CLO()
    WAI(32)
    ANP("Misery1","magic_powerful")
    WAI(50)
    ITS("Fireball")
    ITP("GhostFire")
    CMU("CS_Fanfale1")
    GIT("GhostFire")
    MS3("=火球=")
    CAT("\n升级成了 =幽灵火球=")WAI(160)NOD()RMU()CLR()GIT()
    AMC("ghostfire_get")
    FAC("jack_normal")CAT("\n谢谢你帮我们！")NOD()CLR()
    FAC("misery_normal")CAT("不，")NOD()
    FAC("misery_excite")CAT("\n这只是能让我欣赏到")
    CAT("\n你们垂死挣扎表演的准备工作。")NOD()CLR()
    CAT("\n祝你们今天愉快~")NOD()CLO()
    PMU(1)
    FAO(0)
    TRA("CS_peace_town_hotel","GoFindJenka",15,19)

end

function Misery1Chat_Getout()
    KEY()
    FAC("misery_normal")
    MYB(0,PLY())
    MS3("停下，")WAS()NOD()
    CAT("\n这里只欢迎人类旅客。")NOD()CLO()
    FAO(0)
    MOV(18,12,PLY())
    MOV(19,12,1-PLY())
    SLR(0)
    AMC("normal")
    AMC("hide_gun")
    FAI(2)
    ---[[
    FAC("misery_normal")
    MS3("\n.")WAI(8) CAT(".")WAI(8) CAT(".")WAI(8) CAT(".")WAI(8) CAT(".")WAI(8)CLR()
    CAT("不过，")NOD()
    CAT("\n我记得你们好像是我以前")
    CAT("\n抓过的那几只咪咪卡之一。")NOD()CLR()
    CAT("现在那只小咪咪卡和")
    CAT("\n红眼的都已经复活了..")NOD()CLR()
    CAT("\n你们到这里有何贵干？")NOD()CLR()
    FAC("jack_normal")CAT("最近咪咪卡村附近有怪物出现，")NOD()
    CAT("\n把数和多隆子抓走了，")NOD()
    FAC("jack_><")CAT("\n我想求你帮我找找她们在哪...")NOD()CLR()
    CMU("XXXX")
    FAC("misery_normal")CAT("别做梦了，")NOD()
    CAT("\n我不是你们的灯神。")NOD()CLR()
    FAC("misery_not_well")CAT("\n还有这里宠物禁止入内！")NOD()CLO()
    --]]
    --用泡泡把赶走
    ANP("Misery1","magic")
    SNP("CS_bubble_catcher",16,10,0,"mainLayer","Bubble1")--泡泡
    ANP("Bubble1","set_target")
    ANP("Bubble1",MCN(PLY()))
    WAI(24)
    if(MCN(PLY()) == "CS_mychar_jack") then
        ANP("Bubble1","caught_jack")
    else
        ANP("Bubble1","caught_santa")
    end
    HMC(PLY())
    SOU("CS_021_bubble")
    ANP("Bubble1","set_target")
    ANP("Bubble1","Door_GoPeaceTown")
    WAI(16)
    --捕获玩家2
    ANP("Misery1","magic")
    SNP("CS_bubble_catcher",16,10,0,"mainLayer","Bubble2")--泡泡
    ANP("Bubble2","set_target")
    ANP("Bubble2",MCN(1-PLY()))
    WAI(24)
    SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)
    if(MCN(1-PLY()) == "CS_mychar_jack") then
        ANP("Bubble2","caught_jack")
    else
        ANP("Bubble2","caught_santa")
    end
    HMC(1-PLY())
    SOU("CS_021_bubble")
    ANP("Bubble2","set_target")
    ANP("Bubble2","Door_GoPeaceTown")
    WAI(32)
    DNP("Bubble1")
    WAI(36)
    DNP("Bubble2")
    FAO(2)TRA("CS_peace_town","GetOutDivination",20,31)
end

function KazumaMSG()
    KEY()
    SNP("CS_kazuma_animate",20,12,1,"mainLayer","Kazuma1")
    ANP("Kazuma1","back")
    SNP("CS_sakamoto_sue_animate",18,12,0,"mainLayer","SakamotoSue1")
    FAI(0)
    WAI(16)
    CMU("CS_Kodou")
    FAC("kazuma_normal")MS3("大事不好了！")NOD()
    CAT("\n魔女说库特和卡莉")
    CAT("\n很可能会在这次救援中牺牲。")NOD()CLR()
    FAC("professorbooster_normal")CAT("\n为什么？")NOD()CLR()
    FAC("kazuma_normal")CAT("具体我也不太清楚，")
    CAT("\n总之如果你找到小狗后，")NOD()
    CAT("\n就赶快飞往高第城吧！")NOD()CLR()
    CAT("\n我之后马上也会坐飞龙一同前往。")NOD()CLR()
    FAC("professorbooster_normal")CAT("\n明白了。")NOD()CLO()
    FAO(2)
    TRA("CS_soapcastle_golemhall","ProfessorBoosterGoGaudiCity",41,18)
end

function Credit_Cut()
    KEY()
    FAI(2)
    WAI(32)
    ANP("Door_GoPeaceTown",0,1)
    SNP("CS_quote_animate",28,12,0,"mainLayer","Quote1")
    WAI(16)
    ANP("Quote1","walk",0)
    WAI(16)
    SNP("CS_curly_animate",28,12,0,"mainLayer","Curly1")
    WAI(16)
    ANP("Door_GoPeaceTown",0,0)
    ANP("Curly1","walk",0)
    WAI(8*16)
    ANP("Quote1","normal",0)
    WAI(16)
    ANP("Curly1","normal",0)
    WAI(32)
    SNP("CS_speechbubble",16,11,1,"mainLayer","Speechbubble1")
    ANP("Speechbubble1","ls_speechbubble_miseryrescue")
    WAI(200)
    DNP("Speechbubble1")
    WAI(60)
    ANP("Misery1","bill")
    WAI(32)
    ANP("Misery1","normal")
    ANP("Quote1","bill",0)
    WAI(32)
    ANP("Quote1","bill",1)
    WAI(60)
    ANP("Quote1","lie",0)
    ANP("Quote1","smoke")
    SOU("CS_071_little_crash")
    SNP("CS_bill",18,12,0,"mainLayer","Bill1")
    WAI(60)
    ANP("Curly1","--")
    WAI(200)
    FAO(2)
    TRA("CS_credit","Credit_Cut7",0,0)
end
